@@ -298,7 +298,8 @@ void Kwave::MenuNode::insertNode(const QString &name,
 	    if (!sub) return;
 	}
 
-	if (p[0] == QLatin1Char('#')) sub->specialCommand(p);
+	if (p.length() && (p[0] == QLatin1Char('#')))
+	    sub->specialCommand(p);
 
     } else {
 	// somewhere in the tree
@@ -309,7 +310,7 @@ void Kwave::MenuNode::insertNode(const QString &name,
 	    // remove the "leaf" and insert a branch with
 	    // the same properties
 	    sub = leafToBranch(sub);
-	} else if (!p.length() || (p[0] == QLatin1Char('#')) ) {
+	} else if (p[0] == QLatin1Char('#')) {
 	    // branch already exists and we are at the end of parsing
 	    // -> maybe we want to set new properties
 	    if (!shortcut.isEmpty()) sub->setShortcut(shortcut);
